Registrace | OiRA

Témata

# Registrace

## Proč se musím zaregistrovat?

Při zahájení prvního hodnocení rizik budete nejdříve vyzváni, abyste vytvořili účet OiRA - jedná se o jednoduchý a rychlý proces.

Registrace vám umožňuje se kdykoli přihlásit a získat přístup ke svým údajům, pokračovat v předchozích hodnoceních nebo začít s novými.

Registrace znamená, že systém OiRA může ukládat všechny vaše relace a vaše údaje budou vždy k dispozici.

Přečtěte si naše zásady ochrany soukromých údajů a zjistěte, jak nakládáme s vašimi osobními údaji.

## Jaký je rozdíl mezi registrací uživatele a uskutečněním testovací relace?

Testovací relace umožňuje zúčastněným stranám seznámit se s nástrojem před tím, než se rozhodnou zaregistrovat. Během testovací relace však vaše údaje nejsou uloženy a nebudete moci získat žádné informace, které jste zadali později. Testovací relace vám neumožňuje tisknout zprávy, zatímco registrace vašeho účtu vám umožní své hodnocení rizik plně zdokumentovat.

## Registrace nového účtu

Je to vaše první návštěva? Abyste mohli začít, proveďte tyto jednoduché kroky:

1.) Pro zobrazení registračního formuláře klikněte na tlačítko „Registrovat“.

Registrační formulář.

2.) Zadejte svou e-mailovou adresu a zvolte heslo (dvakrát).

3.) Pro registraci nového účtu klikněte na tlačítko „Další“.

4.) Než budete pokračovat, přečtěte si a přijměte zásady ochrany soukromých údajů.

Nyní budete přihlášeni do systému OiRA.

## Přihlášení ke stávajícímu účtu

Pokud jste se již zaregistrovali, přístup ke svému účtu získáte takto:

1.) Přejděte na přihlašovací formulář. Pokaždé, když se pokusíte o přístup k aplikaci OiRA, zobrazí se odkaz na přihlašovací formulář, a to do doby, než se přihlásíte.

Přihlašovací formulář.

2.) Vyplňte svou e-mailovou adresu a heslo.

3.) Přihlaste se kliknutím na tlačítko „Přihlásit se“.

Jakmile se přihlásíte, zobrazí se níže uvedená obrazovka. Zde můžete zahájit nové hodnocení rizik nebo se vrátit k hodnocení rizik, které jste již zahájili.

Přehled.

Nové hodnocení rizik začněte zadáním názvu (např. Moje-společnost 2018-07-03), nebo přejděte k některému ze svých předchozích hodnocení rizik. Všechna vaše hodnocení rizik jsou uložena pro budoucí použití, pokud se nerozhodnete je vymazat.

Scroll to top Load toolbar…
Back

## 1-registration.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More